# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-02-02 07:26
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0010_merge_20180202_0726'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='productunique',
            unique_together=set([]),
        ),
    ]
