# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-18 06:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0004_auto_20180117_1745'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attribute',
            name='price',
            field=models.FloatField(default=0, verbose_name='Price'),
        ),
        migrations.AlterField(
            model_name='feature',
            name='price',
            field=models.FloatField(default=0, verbose_name='Price'),
        ),
        migrations.AlterField(
            model_name='featurespecial',
            name='price',
            field=models.FloatField(default=0, verbose_name='Price'),
        ),
    ]
