# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-17 15:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('codenerix_products', '0001_initial'),
        ('codenerix_storages', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='productunique',
            name='box',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products_unique', to='codenerix_storages.StorageBox', verbose_name='Box'),
        ),
        migrations.AddField(
            model_name='productunique',
            name='product_final',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_unique', to='codenerix_products.ProductFinal', verbose_name='Product final'),
        ),
        migrations.AddField(
            model_name='producttexttextes',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Product'),
        ),
        migrations.AddField(
            model_name='producttexttexten',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Product'),
        ),
        migrations.AddField(
            model_name='productrelationsold',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_related', to='codenerix_products.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='productrelationsold',
            name='related',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_related_sold', to='codenerix_products.Product', verbose_name='Products related'),
        ),
        migrations.AddField(
            model_name='productimagetextes',
            name='product_image',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.ProductImage'),
        ),
        migrations.AddField(
            model_name='productimagetexten',
            name='product_image',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.ProductImage'),
        ),
        migrations.AddField(
            model_name='productimage',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_image', to='codenerix_products.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='productfinaltextes',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.ProductFinal'),
        ),
        migrations.AddField(
            model_name='productfinaltexten',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.ProductFinal'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontextes',
            name='product_final_option',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.ProductFinalOption'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontexten',
            name='product_final_option',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.ProductFinalOption'),
        ),
        migrations.AddField(
            model_name='productfinaloption',
            name='product_final',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='productfinals_option', to='codenerix_products.ProductFinal', verbose_name='Product Final'),
        ),
        migrations.AddField(
            model_name='productfinaloption',
            name='products_pack',
            field=models.ManyToManyField(related_name='productfinals_optionpack', to='codenerix_products.ProductFinal'),
        ),
        migrations.AddField(
            model_name='productfinalimagetextes',
            name='product_final_image',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.ProductFinalImage'),
        ),
        migrations.AddField(
            model_name='productfinalimagetexten',
            name='product_final_image',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.ProductFinalImage'),
        ),
        migrations.AddField(
            model_name='productfinalimage',
            name='product_final',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='productfinals_image', to='codenerix_products.ProductFinal', verbose_name='Product Final'),
        ),
        migrations.AddField(
            model_name='productfinalattribute',
            name='attribute',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products_final_attr', to='codenerix_products.Attribute', verbose_name='Attributes'),
        ),
        migrations.AddField(
            model_name='productfinalattribute',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_final_attr', to='codenerix_products.ProductFinal', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='productfinal',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_final', to='codenerix_products.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='productfinal',
            name='related',
            field=models.ManyToManyField(blank=True, related_name='productsrelated', to='codenerix_products.ProductFinal'),
        ),
        migrations.AddField(
            model_name='productfinal',
            name='related_accesory',
            field=models.ManyToManyField(blank=True, related_name='productsrelatedaccesory', to='codenerix_products.ProductFinal'),
        ),
        migrations.AddField(
            model_name='productfeature',
            name='feature',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='product_features', to='codenerix_products.Feature', verbose_name='Feature'),
        ),
        migrations.AddField(
            model_name='productfeature',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='product_features', to='codenerix_products.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='productdocumenttextes',
            name='product_document',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.ProductDocument'),
        ),
        migrations.AddField(
            model_name='productdocumenttexten',
            name='product_document',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.ProductDocument'),
        ),
        migrations.AddField(
            model_name='productdocument',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_document', to='codenerix_products.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='product',
            name='brand',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.Brand', verbose_name='Brand'),
        ),
        migrations.AddField(
            model_name='product',
            name='category',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.Category', verbose_name='Category'),
        ),
        migrations.AddField(
            model_name='product',
            name='family',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.Family', verbose_name='Family'),
        ),
        migrations.AddField(
            model_name='product',
            name='feature_special',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.FeatureSpecial', verbose_name='Feature special'),
        ),
        migrations.AddField(
            model_name='product',
            name='subcategory',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.Subcategory', verbose_name='Subcategory'),
        ),
        migrations.AddField(
            model_name='product',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.TypeTax', verbose_name='Tax (%)'),
        ),
        migrations.AddField(
            model_name='optionvaluefeaturetextes',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.OptionValueFeature'),
        ),
        migrations.AddField(
            model_name='optionvaluefeaturetexten',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.OptionValueFeature'),
        ),
        migrations.AddField(
            model_name='optionvaluefeaturespecialtextes',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.OptionValueFeatureSpecial'),
        ),
        migrations.AddField(
            model_name='optionvaluefeaturespecialtexten',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.OptionValueFeatureSpecial'),
        ),
        migrations.AddField(
            model_name='optionvaluefeaturespecial',
            name='group',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='options_value_feature_special', to='codenerix_products.GroupValueFeatureSpecial', verbose_name='Options value'),
        ),
        migrations.AddField(
            model_name='optionvaluefeature',
            name='group',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='options_value_feature', to='codenerix_products.GroupValueFeature', verbose_name='Options value'),
        ),
        migrations.AddField(
            model_name='optionvalueattributetextes',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.OptionValueAttribute'),
        ),
        migrations.AddField(
            model_name='optionvalueattributetexten',
            name='option_value',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.OptionValueAttribute'),
        ),
        migrations.AddField(
            model_name='optionvalueattribute',
            name='group',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='options_value_attribute', to='codenerix_products.GroupValueAttribute', verbose_name='Options value'),
        ),
        migrations.AddField(
            model_name='flagshipproducttextes',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.FlagshipProduct'),
        ),
        migrations.AddField(
            model_name='flagshipproducttexten',
            name='product',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.FlagshipProduct'),
        ),
        migrations.AddField(
            model_name='flagshipproduct',
            name='product_final',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='flagship_products', to='codenerix_products.ProductFinal', verbose_name='Flagship product'),
        ),
        migrations.AddField(
            model_name='featuretextes',
            name='feature',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Feature'),
        ),
        migrations.AddField(
            model_name='featuretexten',
            name='feature',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Feature'),
        ),
        migrations.AddField(
            model_name='featurespecialtextes',
            name='feature_special',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.FeatureSpecial'),
        ),
        migrations.AddField(
            model_name='featurespecialtexten',
            name='feature_special',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.FeatureSpecial'),
        ),
        migrations.AddField(
            model_name='featurespecial',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='feature_specials', to='codenerix_products.Category', verbose_name='Category'),
        ),
        migrations.AddField(
            model_name='featurespecial',
            name='family',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='feature_specials', to='codenerix_products.Family', verbose_name='Family'),
        ),
        migrations.AddField(
            model_name='featurespecial',
            name='list_value',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='feature_specials', to='codenerix_products.GroupValueFeatureSpecial', verbose_name='List value'),
        ),
        migrations.AddField(
            model_name='feature',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='features', to='codenerix_products.Category', verbose_name='Category'),
        ),
        migrations.AddField(
            model_name='feature',
            name='family',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='features', to='codenerix_products.Family', verbose_name='Family'),
        ),
        migrations.AddField(
            model_name='feature',
            name='list_value',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='features', to='codenerix_products.GroupValueFeature', verbose_name='List value'),
        ),
        migrations.AddField(
            model_name='familytextes',
            name='family',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Family'),
        ),
        migrations.AddField(
            model_name='familytexten',
            name='family',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Family'),
        ),
        migrations.AddField(
            model_name='categorytextes',
            name='category',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Category'),
        ),
        migrations.AddField(
            model_name='categorytexten',
            name='category',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Category'),
        ),
        migrations.AddField(
            model_name='category',
            name='family',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='categories', to='codenerix_products.Family', verbose_name='Family'),
        ),
        migrations.AddField(
            model_name='brandtextes',
            name='brand',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Brand'),
        ),
        migrations.AddField(
            model_name='brandtexten',
            name='brand',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Brand'),
        ),
        migrations.AddField(
            model_name='attributetextes',
            name='attribute',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Attribute'),
        ),
        migrations.AddField(
            model_name='attributetexten',
            name='attribute',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Attribute'),
        ),
        migrations.AddField(
            model_name='attribute',
            name='attribute',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='attributes', to='codenerix_products.Attribute', verbose_name='Attribute'),
        ),
        migrations.AddField(
            model_name='attribute',
            name='category',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='attributes', to='codenerix_products.Category', verbose_name='Category'),
        ),
        migrations.AddField(
            model_name='attribute',
            name='family',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='attributes', to='codenerix_products.Family', verbose_name='Family'),
        ),
        migrations.AddField(
            model_name='attribute',
            name='list_value',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='attributes', to='codenerix_products.GroupValueAttribute', verbose_name='List value'),
        ),
        migrations.AlterUniqueTogether(
            name='productunique',
            unique_together=set([('product_final', 'value')]),
        ),
        migrations.AlterUniqueTogether(
            name='productrelationsold',
            unique_together=set([('product', 'related')]),
        ),
    ]
