# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-26 16:11
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0007_auto_20180123_1316'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='productfinal',
            name='stock_lock',
        ),
        migrations.RemoveField(
            model_name='productfinal',
            name='stock_real',
        ),
    ]
