# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-17 15:28
from __future__ import unicode_literals

import codenerix.fields
import codenerix.lib.helpers
import codenerix_products.models
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Attribute',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('type_value', models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value')),
                ('price', models.FloatField(default=0, verbose_name='Price')),
                ('type_price', models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='AttributeTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='AttributeTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Brand',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('outstanding', models.BooleanField(default=True, verbose_name='Outstanding')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('show_menu', models.BooleanField(default=True, verbose_name='Show menu')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BrandTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BrandTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('code', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Code')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('show_menu', models.BooleanField(default=True, verbose_name='Show menu')),
                ('show_only_product_stock', models.BooleanField(default=True, verbose_name='Show only products in stock')),
                ('image', codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja un tamaño comprendido entre 1200px y 2000px', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('icon', codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja que sea una imagen superior a 200px transparente y en formato png o svg', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Icon')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CategoryTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CategoryTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Family',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('code', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Code')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('show_menu', models.BooleanField(default=True, verbose_name='Show menu')),
                ('icon', codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja que sea una imagen superior a 200px transparente y en formato png o svg', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Icon')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Feature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('type_value', models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value')),
                ('price', models.FloatField(default=0, verbose_name='Price')),
                ('type_price', models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FeatureSpecial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('type_value', models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value')),
                ('price', models.FloatField(default=0, verbose_name='Price')),
                ('type_price', models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('unique', models.BooleanField(default=True, verbose_name='The value must unique')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FeatureSpecialTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FeatureSpecialTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FeatureTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FeatureTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FlagshipProduct',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('view_video', models.BooleanField(default=False, verbose_name='View video')),
                ('orientazion', models.CharField(choices=[('R', 'Right'), ('L', 'Left')], default='R', max_length=2, verbose_name='Orientazion')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
            bases=(codenerix_products.models.CustomQueryMixin, models.Model),
        ),
        migrations.CreateModel(
            name='FlagshipProductTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('title', models.CharField(max_length=250, verbose_name='Text alternavive image')),
                ('description', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FlagshipProductTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('title', models.CharField(max_length=250, verbose_name='Text alternavive image')),
                ('description', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GroupValueAttribute',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('name', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Name')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GroupValueFeature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('name', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Name')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GroupValueFeatureSpecial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('name', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Name')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueAttribute',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueAttributeTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueAttributeTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureSpecial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureSpecialTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureSpecialTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('model', models.CharField(blank=True, max_length=250, null=True, verbose_name='Model')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('code', models.CharField(max_length=250, unique=True, verbose_name='Code')),
                ('price_base', models.FloatField(default=0, verbose_name='Price base')),
                ('of_sales', models.BooleanField(default=True, verbose_name='Sales')),
                ('of_purchase', models.BooleanField(default=True, verbose_name='Purchase')),
                ('force_stock', models.BooleanField(default=True, verbose_name='Force stock')),
                ('url_video', models.CharField(blank=True, max_length=250, null=True, verbose_name='Url Video')),
                ('packing_cost', models.FloatField(default=0, verbose_name='Packing cost')),
                ('weight', models.FloatField(default=0, verbose_name='Weight')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
            bases=(codenerix_products.models.CustomQueryMixin, models.Model),
        ),
        migrations.CreateModel(
            name='ProductDocument',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('doc_path', codenerix.fields.FileAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Doc Path')),
                ('name_file', models.CharField(max_length=254, verbose_name='Name')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductDocumentTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductDocumentTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFeature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('value', models.CharField(max_length=80, verbose_name='Value')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinal',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('offer', models.BooleanField(default=False, verbose_name='Offer')),
                ('outstanding', models.BooleanField(default=False, verbose_name='Outstanding')),
                ('most_sold', models.BooleanField(default=False, verbose_name='Most sold')),
                ('stock_real', models.FloatField(default=0, editable=False, verbose_name='Stock real')),
                ('stock_lock', models.FloatField(default=0, editable=False, verbose_name='Stock lock')),
                ('price_base', models.FloatField(default=0, editable=False, verbose_name='Price base')),
                ('price', models.FloatField(default=0, editable=False, verbose_name='Price')),
                ('ean13', models.CharField(blank=True, max_length=13, null=True, verbose_name='EAN-13')),
                ('reviews_value', models.FloatField(default=0, editable=False, verbose_name='Reviews')),
                ('reviews_count', models.IntegerField(default=0, editable=False, verbose_name='Reviews count')),
                ('sample', models.BooleanField(default=False, help_text='If this option is checked the product can not be sold', verbose_name='Sample')),
                ('code', models.CharField(blank=True, help_text='If it is empty, code is equal to code product', max_length=250, null=True, unique=True, verbose_name='Code')),
                ('price_base_local', models.FloatField(blank=True, help_text='If it is empty, price base is equal to price base of product', null=True, verbose_name='Price base')),
                ('packing_cost', models.FloatField(blank=True, help_text='If it is empty, packing cost is equal to packing cost of product', null=True, verbose_name='Packing cost')),
                ('weight', models.FloatField(blank=True, help_text='If it is empty, weight is equal to weight of product', null=True, verbose_name='Weight')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
            bases=(codenerix_products.models.CustomQueryMixin, models.Model),
        ),
        migrations.CreateModel(
            name='ProductFinalAttribute',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('value', models.CharField(max_length=80, verbose_name='Value')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('principal', models.BooleanField(default=False, verbose_name='Principal')),
                ('flagship_product', models.BooleanField(default=False, verbose_name='Flagship product')),
                ('outstanding', models.BooleanField(default=False, verbose_name='Outstanding')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalImageTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalImageTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalOption',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('active', models.BooleanField(default=True, verbose_name='Active')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalOptionTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalOptionTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('tags', models.TextField(blank=True, null=True, verbose_name='TAGs')),
                ('description_sample', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Sample description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('tags', models.TextField(blank=True, null=True, verbose_name='TAGs')),
                ('description_sample', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Sample description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('principal', models.BooleanField(default=False, verbose_name='Principal')),
                ('flagship_product', models.BooleanField(default=False, verbose_name='Flagship product')),
                ('outstanding', models.BooleanField(default=False, verbose_name='Outstanding')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductImageTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductImageTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductRelationSold',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('hits', models.SmallIntegerField(blank=True, null=True, verbose_name='Hits')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductTextTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('tags', models.TextField(blank=True, null=True, verbose_name='TAGs')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductTextTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('tags', models.TextField(blank=True, null=True, verbose_name='TAGs')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductUnique',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('value', models.CharField(blank=True, max_length=80, null=True, verbose_name='Value')),
                ('stock_real', models.FloatField(default=0, verbose_name='Stock real')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Subcategory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('code', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Code')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('show_menu', models.BooleanField(default=True, verbose_name='Show menu')),
                ('show_brand', models.BooleanField(default=True, verbose_name='Show brand (for menu)')),
                ('outstanding', models.BooleanField(default=False, verbose_name='Outstanding')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('image', codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja un tamaño comprendido entre 1200px y 2000px', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('icon', codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja que sea una imagen superior a 200px transparente y en formato png o svg', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Icon')),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='subcategory', to='codenerix_products.Category', verbose_name='Category')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SubcategoryTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('subcategory', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Subcategory')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SubcategoryTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('meta_keywords', models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('subcategory', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Subcategory')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TypeTax',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('tax', models.FloatField(validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)], verbose_name='Tax (%)')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('default', models.BooleanField(default=False, verbose_name='Default')),
                ('recargo_equivalencia', models.FloatField(validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)], verbose_name='Recargo de equivalencia (%)')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
    ]
