# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-04-26 12:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0011_auto_20180202_0826'),
    ]

    operations = [
        migrations.AddField(
            model_name='productunique',
            name='caducity',
            field=models.DateField(blank=True, default=None, null=True, verbose_name='Caducity'),
        ),
    ]
