# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-02-02 06:26
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0009_auto_20180201_1137'),
        ('codenerix_products', '0007_product_caducable'),
    ]

    operations = [
    ]
