# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-17 15:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0002_auto_20180117_1628'),
    ]

    operations = [
        migrations.AlterField(
            model_name='product',
            name='packing_cost',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=10, verbose_name='Packing cost'),
        ),
        migrations.AlterField(
            model_name='productfinal',
            name='packing_cost',
            field=models.DecimalField(blank=True, decimal_places=2, help_text='If it is empty, packing cost is equal to packing cost of product', max_digits=10, null=True, verbose_name='Packing cost'),
        ),
    ]
