# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-02-01 10:37
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0008_auto_20180126_1711'),
    ]

    operations = [
        migrations.AlterField(
            model_name='productunique',
            name='box',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='products_unique', to='codenerix_storages.StorageBox', verbose_name='Box'),
        ),
        migrations.AlterField(
            model_name='productunique',
            name='stock_original',
            field=models.FloatField(default=0, verbose_name='Stock original'),
        ),
    ]
