# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-25 07:25
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0006_auto_20180118_1126'),
    ]

    operations = [
        migrations.AddField(
            model_name='product',
            name='caducable',
            field=models.BooleanField(default=False, verbose_name='Caducable'),
        ),
    ]
