# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-23 12:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0006_auto_20180118_1126'),
    ]

    operations = [
        migrations.AddField(
            model_name='productunique',
            name='stock_locked',
            field=models.FloatField(default=0, editable=False, verbose_name='Stock locked'),
        ),
        migrations.AddField(
            model_name='productunique',
            name='stock_original',
            field=models.FloatField(default=0, editable=False, verbose_name='Stock original'),
        ),
        migrations.AlterField(
            model_name='productunique',
            name='stock_real',
            field=models.FloatField(default=0, editable=False, verbose_name='Stock real'),
        ),
    ]
